==> bw-timezone-server-web-5.0.3-sources.jar: org/bedework/timezones/server/OptionsMethod.java <==
/* ********************************************************************
    Licensed to Jasig under one or more contributor license
    agreements. See the NOTICE file distributed with this work
    for additional information regarding copyright ownership.
    Jasig licenses this file to you under the Apache License,
    Version 2.0 (the "License"); you may not use this file
    except in compliance with the License. You may obtain a
    copy of the License at:

    http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing,
    software distributed under the License is distributed on
    an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
    KIND, either express or implied. See the License for the
    specific language governing permissions and limitations
    under the License.
*/
package org.bedework.timezones.server;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/** Class called to handle OPTIONS. We should determine what the current
 * url refers to and send a response which shows the allowable methods on that
 * resource.
 *
 *   @author Mike Douglass
 */
public class OptionsMethod extends MethodBase {
  /**
   * @throws ServletException
   */
  public OptionsMethod() throws ServletException {
    super();
  }

  @Override
  public void doMethod(HttpServletRequest req,
                        HttpServletResponse resp) throws ServletException {
    if (debug()) {
      debug("OptionsMethod: doMethod");
    }

    try {
      resp.addHeader("Allow", "OPTIONS, GET");
    } catch (Throwable t) {
      throw new ServletException(t);
    }
  }
}

==> bw-timezone-server-web-5.0.8-sources.jar: org/bedework/timezones/server/OptionsMethod.java <==
/* ********************************************************************
    Licensed to Jasig under one or more contributor license
    agreements. See the NOTICE file distributed with this work
    for additional information regarding copyright ownership.
    Jasig licenses this file to you under the Apache License,
    Version 2.0 (the "License"); you may not use this file
    except in compliance with the License. You may obtain a
    copy of the License at:

    http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing,
    software distributed under the License is distributed on
    an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
    KIND, either express or implied. See the License for the
    specific language governing permissions and limitations
    under the License.
*/
package org.bedework.timezones.server;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/** Class called to handle OPTIONS. We should determine what the current
 * url refers to and send a response which shows the allowable methods on that
 * resource.
 *
 *   @author Mike Douglass
 */
public class OptionsMethod extends MethodBase {
  /**
   * @throws ServletException on error
   */
  public OptionsMethod() throws ServletException {
    super();
  }

  @Override
  public void doMethod(final HttpServletRequest req,
                       final HttpServletResponse resp) throws ServletException {
    if (debug()) {
      debug("OptionsMethod: doMethod");
    }

    try {
      resp.addHeader("Allow", "OPTIONS, GET");
    } catch (final Throwable t) {
      throw new ServletException(t);
    }
  }
}
